/*
    $Id: testassert.c,v 1.2 2008/03/22 18:08:25 karl Exp $

    Copyright (C) 2001, 2008 Herbert Valerio Riedel <hvr@gnu.org>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifdef HAVE_CONFIG_H
# include "config.h"
#endif

/* Private headers */
#include "cdio_assert.h"

int
main (int argc, const char *argv[])
{
  cdio_assert (argc < 2);

  cdio_assert_not_reached ();

  return 0;
}
